CMS MessageLogger: Establishing a Destination to the cout Stream

#

# CMS MessageLogger Service
Establishing a Destination to the cout Stream

    process TEST = {

      service = MessageLogger {
        vstring destinations = {   "detailedInfo.txt"
                          , "critical.txt"
                          , "cout"
                          , "cerr"
                                                 }
        PSet critical.txt     = { string threshold = "ERROR"   }
        PSet detailedInfo.txt = { string threshold = "INFO"    }
        PSet cerr             = { string threshold = "WARNING" }
      }
      untracked PSet maxEvents = {untracked int32 input = 5}
      path p = { myAnalysisModule }
      module myAnalysisModule = ModuleThatIssuesMessages { }
      source = EmptySource { }
    }

The { ..., "cout", ... } in the list of destinations refers to message information streamed to std::cout rather than to a file named cout. In this configuration file, no threshold is set for cout; the destination writing to cout will react to every message. Also, this configuration file establishes destinations to cout and cerr for illustration purposes, but in practice it would be confusing to send to both, since unless one or the other of the streams is re-directed, the output would appear entangled.

The MessageLogger service provides no way to create a destination writing to an ordinary file named cout or cerr.

USCMS Software and Computing Home Page - CMS MessageLogger Service Page - Configuration File

Last modified: November 29, 2005